package com.dayou.controller;

import com.dayou.utils.LoginContext;
import org.apache.poi.xssf.usermodel.XSSFWorkbook;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.RequestMapping;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.core.metadata.IPage;
import org.springframework.web.bind.annotation.RestController;
import com.dayou.controller.BaseController;
import com.dayou.service.IBusinessProductionBonusPointsService;
import com.dayou.entity.BusinessProductionBonusPoints;
import com.dayou.common.RestResponse;
import org.springframework.web.bind.annotation.*;
import com.dayou.utils.ConvertUtil;
import com.dayou.utils.HttpKit;
import com.dayou.exception.ErrorCode;
import java.util.Date;
import java.util.List;
import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import org.springframework.http.MediaType;
import org.springframework.web.multipart.MultipartFile;
/**
 * 业务产品额外加减分(如疑难项目、总经理、部门综合加减分等)
 *
 * @author wucl
 * @since 2025-05-28
 */
@RestController
@RequestMapping("businessProductionBonusPoints")
@Slf4j
public class BusinessProductionBonusPointsController extends BaseController {
    @Autowired
    private IBusinessProductionBonusPointsService businessProductionBonusPointsService;

    /**
    * 业务产品额外加减分(如疑难项目、总经理、部门综合加减分等)列表
    */
    @GetMapping("")
    public RestResponse<Page<BusinessProductionBonusPoints>> page(BusinessProductionBonusPoints businessProductionBonusPoints, Page page){
        Page<BusinessProductionBonusPoints> pages=businessProductionBonusPointsService.selectPage(page,businessProductionBonusPoints);
        return RestResponse.data(pages);
    }

    /**
     * 业务产品额外加减分(如疑难项目、总经理、部门综合加减分等)详情
     */
    @GetMapping("/{id}")
    public RestResponse<BusinessProductionBonusPoints> detail(@PathVariable Long id){
        BusinessProductionBonusPoints xBusinessProductionBonusPoints =businessProductionBonusPointsService.detail(id);
        return RestResponse.data(xBusinessProductionBonusPoints);
     }

    /**
     * 业务产品额外加减分(如疑难项目、总经理、部门综合加减分等)新增
     */
    @PostMapping("")
    public RestResponse<Boolean> save(@RequestBody BusinessProductionBonusPoints businessProductionBonusPoints) {
        Boolean ret = businessProductionBonusPointsService.add(businessProductionBonusPoints);
        return RestResponse.data(ret);
    }

    /**
     * 批量新增或更新
     * 业务产品额外加减分(如疑难项目、总经理、部门综合加减分等)
     */
    @PostMapping("/saveOrUpdate")
    public RestResponse<Boolean> saveOrUpdate(@RequestBody List<BusinessProductionBonusPoints> points) {
        for (BusinessProductionBonusPoints businessProductionBonusPoints : points) {
            businessProductionBonusPoints.setOperatorId(LoginContext.getCurrentUserId());
        }
        Boolean ret = businessProductionBonusPointsService.saveOrUpdateBatch(points);
        return RestResponse.data(ret);
    }

    /**
     * 业务产品额外加减分(如疑难项目、总经理、部门综合加减分等)更新
     */
    @PutMapping("")
    public RestResponse<Boolean> update(@RequestBody BusinessProductionBonusPoints businessProductionBonusPoints) {
        Boolean ret = businessProductionBonusPointsService.update(businessProductionBonusPoints);
        return RestResponse.data(ret);
    }

    /**
     * 业务产品额外加减分(如疑难项目、总经理、部门综合加减分等)删除
     */
    @DeleteMapping("/{id}")
    public RestResponse<Boolean> delete(@PathVariable Long id) {
        Boolean ret = businessProductionBonusPointsService.delete(id);
        return RestResponse.data(ret);
    }

    /**
     * 根据产品id与业务类型查询额外加减分信息集合
     * @param productionId 产品id
     * @param businessType 业务类型
     * @return List<BusinessProductionBonusPoints>
     */
    @GetMapping("getList/{productionId}/{businessType}")
    public RestResponse<List<BusinessProductionBonusPoints>> getList(@PathVariable Long productionId, @PathVariable String businessType) {
        return RestResponse.data(businessProductionBonusPointsService.getList(productionId, businessType));
    }


}

