package com.dayou.controller;

import com.dayou.annotation.IgnoreAuth;
import com.dayou.dto.FinanceFineSelectDTO;
import com.dayou.vo.FinanceFineVO;
import org.apache.poi.xssf.usermodel.XSSFWorkbook;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.RequestMapping;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.core.metadata.IPage;
import org.springframework.web.bind.annotation.RestController;
import com.dayou.controller.BaseController;
import com.dayou.service.IFinanceFineService;
import com.dayou.entity.FinanceFine;
import com.dayou.common.RestResponse;
import org.springframework.web.bind.annotation.*;
import com.dayou.utils.ConvertUtil;
import com.dayou.utils.HttpKit;
import com.dayou.exception.ErrorCode;

import java.io.IOException;
import java.util.Date;
import java.util.List;
import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import org.springframework.http.MediaType;
import org.springframework.web.multipart.MultipartFile;

import javax.servlet.http.HttpServletResponse;

import static com.dayou.enums.MainBusinessEnum.*;

/**
 * 超期未收款罚款表
 *
 * @author GouGengquan
 * @since 2025-04-07
 */
@RestController
@RequestMapping("financeFine")
@Slf4j
public class FinanceFineController extends BaseController {
    @Autowired
    private IFinanceFineService financeFineService;

    /**
    * 超期未收款罚款表列表
    */
    @GetMapping("/page")
    public RestResponse<Page<FinanceFineVO>> page(Page page, FinanceFineSelectDTO financeFineSelectDTO){
        Page<FinanceFineVO> pages=financeFineService.selectPage(page,financeFineSelectDTO);
        return RestResponse.data(pages);
    }

    /**
     * 导出罚款记录
     * @param dto 查询条件
     */
    @GetMapping("/export")
    public void exportList(FinanceFineSelectDTO dto, HttpServletResponse response) throws IOException {
        List<FinanceFineVO> financeFineVOList = financeFineService.exportList(dto);
        String businessName = null;
        if (dto.getBusinessType().equals(ASSET_BUSINESS.getCode())) {
            businessName = ASSET_BUSINESS.getMsg();
        } else if (dto.getBusinessType().equals(MAJOR_BUSINESS.getCode())) {
            businessName = MAJOR_BUSINESS.getMsg();
        } else {
            businessName = PERSONAL_BUSINESS.getMsg();
        }
        exportPlus(response,businessName + "_罚款记录",financeFineVOList, FinanceFineVO.class);
    }

    /**
     * 取消确认罚款金额
     * @return Boolean
     */
    @PutMapping("/cancel/{id}")
    public RestResponse<Boolean> cancelFineAmount(@PathVariable Long id) {
        return RestResponse.data(financeFineService.cancelFineAmount(id));
    }

    /**
     * 确认罚款金额
     * @return Boolean
     */
    @PutMapping("/confirm/{id}")
    public RestResponse<Boolean> confirmFineAmount(@PathVariable Long id) {
        return RestResponse.data(financeFineService.confirmFineAmount(id));
    }

    /**
     * 批量取消确认罚款金额
     * @return Boolean
     */
    @PutMapping("/cancel/batch")
    public RestResponse<Boolean> batchCancelFineAmount(@RequestBody List<Long> ids) {
       return RestResponse.data(financeFineService.batchCancelFineAmount(ids));
    }

    /**
     * 超期未收款罚款表详情
     */
    @GetMapping("/{id}")
    public RestResponse<FinanceFine> detail(@PathVariable Long id){
        FinanceFine xFinanceFine =financeFineService.detail(id);
        return RestResponse.data(xFinanceFine);
     }

    /**
     * 超期未收款罚款表新增
     */
    @PostMapping("")
    public RestResponse<Boolean> save(@RequestBody FinanceFine financeFine) {
        Boolean ret = financeFineService.add(financeFine);
        return RestResponse.data(ret);
    }

    /**
     * 超期未收款罚款表更新
     */
    @PutMapping("/update")
    public RestResponse<Boolean> update(@RequestBody FinanceFine financeFine) {
        Boolean ret = financeFineService.update(financeFine);
        return RestResponse.data(ret);
    }

    /**
     * 超期未收款罚款表删除
     */
    @DeleteMapping("/{id}")
    public RestResponse<Boolean> delete(@PathVariable Long id) {
        Boolean ret = financeFineService.delete(id);
        return RestResponse.data(ret);
    }

    /**
     * 手动同步统计财务收款预警中超过270天的订单或产品新增到罚款表
     */
    // @IgnoreAuth
    @GetMapping("/compileFineOrder")
    public void compileFineOrder() {
        financeFineService.compileFineOrder();
    }


}

