package com.dayou.mapper;

import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.dayou.dto.AssetsStatisticalSelectDTO;
import com.dayou.dto.MajorStatisticalSelectDTO;
import com.dayou.vo.*;
import org.apache.ibatis.annotations.Param;

import java.util.List;

public interface MajorStatisticalStatementMapper {

    /**
     * 查询大中型台账
     * @param page 分页
     * @param dto 查询条件
     * @return List<MajorLedgerVO>
     */
    Page<MajorLedgerVO> getMajorLedgerVO(@Param("page") Page page, @Param("dto") MajorStatisticalSelectDTO dto);

    /**
     * 导出大中型台账
     * @param dto 查询条件
     * @return Page<MajorLedgerVO>
     */
    List<MajorLedgerVO> exportMajorLedgerVO(@Param("dto") MajorStatisticalSelectDTO dto);

    /**
     * 评估部绩效扣分查询
     * @param dto 查询dto
     * @return List<MajorPerformanceDeductionVO>
     */
    List<MajorPerformanceDeductionVO> getMajorPerformanceDeductionVO(@Param("dto") MajorStatisticalSelectDTO dto);

    /**
     * 评估人员绩效扣分查询
     * @param dto 查询dto
     * @return List<MajorPerformanceDeductionVO>
     */
    List<MajorPerformanceDeductionVO> getMajorPerformanceDeductionVOByEvaluator(@Param("dto") MajorStatisticalSelectDTO dto);

    /**
     * 根据部门id获取部门绩效扣分
     * @param dto 查询dto
     * @return List<MajorPerformanceDeductionVO>
     */
    List<MajorPerformanceDeductionVO> getMajorPerformanceDeductionVOByDepId(@Param("dto") MajorStatisticalSelectDTO dto);

    /**
     * 获取每种错误类型的数量
     * @param dto 查询dto
     * @return List<MajorErrorTypeCountVO>
     */
    List<MajorErrorTypeCountVO> getMajorErrorTypeCountVO(@Param("dto") MajorStatisticalSelectDTO dto, @Param("self") Boolean self, @Param("dep") Boolean dep);

    /**
     * 查询错误类型详情列表
     * @param page 分页
     * @param dto 查询dto
     * @return Page<MajorPerformanceDeductionDetailVO>
     */
    Page<MajorPerformanceDeductionDetailVO> getMajorErrorTypeDetailVO(@Param("page") Page page, @Param("dto") MajorStatisticalSelectDTO dto);

    /**
     * 导出错误类型详情列表
     * @param dto 查询dto
     * @return List<MajorPerformanceDeductionDetailVO>
     */
    List<MajorPerformanceDeductionDetailVO> exportMajorErrorTypeDetailVO(@Param("dto") MajorStatisticalSelectDTO dto);

    /**
     * 查询错误详情列表
     * @param page 分页
     * @param dto 查询dto
     * @return Page<MajorPerformanceDeductionDetailVO>
     */
    Page<MajorPerformanceDeductionDetailVO> getMajorPerformanceDeductionDetailVO(@Param("page") Page page, @Param("dto") MajorStatisticalSelectDTO dto);

    /**
     * 导出错误详情列表
     * @param dto 查询dto
     * @return List<MajorPerformanceDeductionDetailVO>
     */
    List<MajorPerformanceDeductionDetailVO> exportMajorPerformanceDeductionDetailVO(@Param("dto") MajorStatisticalSelectDTO dto);

    /**
     * 查询额外加减分详情列表
     * @param page 分页
     * @param dto 查询dto
     * @return Page<MajorPerformanceDeductionDetailVO>
     */
    Page<MajorBonusPointsDetailVO> getMajorBonusPointsDetailVO(@Param("page") Page page, @Param("dto") MajorStatisticalSelectDTO dto);

    /**
     * 导出额外加减分详情列表
     * @param dto 查询dto
     * @return List<MajorPerformanceDeductionDetailVO>
     */
    List<MajorBonusPointsDetailVO> exportMajorBonusPointsDetailVO(@Param("dto") MajorStatisticalSelectDTO dto);

    /**
     * 评估部效率查询
     * @param dto 查询dto
     * @return List<MajorEvaluateEfficiencyVO>
     */
    List<MajorEvaluateEfficiencyVO> getMajorEvaluateDepEfficiencyVO(@Param("dto") MajorStatisticalSelectDTO dto);

    /**
     * 评估人员效率查询
     * @param dto 查询dto
     * @return List<MajorEvaluateEfficiencyVO>
     */
    List<MajorEvaluateEfficiencyVO> getMajorEvaluatePerEfficiencyVO(@Param("dto") MajorStatisticalSelectDTO dto);

    /**
     * 效率详情列表查询
     * @param page 分页
     * @param dto 查询dto
     * @return Page<MajorEfficiencyDetailVO>
     */
    Page<MajorEfficiencyDetailVO> getMajorEfficiencyDetailVO(@Param("page") Page page, @Param("dto") MajorStatisticalSelectDTO dto);

    /**
     * 效率详情列表导出
     * @param dto 查询dto
     * @return List<MajorEfficiencyDetailVO>
     */
    List<MajorEfficiencyDetailVO> exportMajorEfficiencyDetailVO(@Param("dto") MajorStatisticalSelectDTO dto);

    /**
     * 产值详情列表查询
     * @param page 分页
     * @param dto 查询dto
     * @return Page<MajorEfficiencyDetailVO>
     */
    Page<MajorOutputValueDetailVO> getMajorOutputValueDetailVO(@Param("page") Page page, @Param("dto") MajorStatisticalSelectDTO dto);


    /**
     * 产值详情列表查询
     * @param dto 查询dto
     * @return Page<MajorEfficiencyDetailVO>
     */
    List<MajorOutputValueDetailVO> exportMajorOutputValueDetailVO(@Param("dto") MajorStatisticalSelectDTO dto);

    /**
     * 项目部绩效查询
     * @param dto 查询dto
     * @return List<MajorEvaluateEfficiencyVO>
     */
    List<MajorDepPerformanceOverviewVO> getMajorDepPerformanceOverviewVO(@Param("dto") MajorStatisticalSelectDTO dto);

    /**
     * 市场部效率查询
     * @param dto 查询dto
     * @return List<MajorMarketEfficiencyVO>
     */
    List<MajorMarketEfficiencyVO> getMajorsMarketDepEfficiencyVO(@Param("dto") MajorStatisticalSelectDTO dto);

    /**
     * 客户经理效率查询
     * @param dto 查询dto
     * @return List<MajorMarketEfficiencyVO>
     */
    List<MajorMarketEfficiencyVO> getMajorMarketPerEfficiencyVO(@Param("dto") MajorStatisticalSelectDTO dto);
}
