package com.dayou.service;

import com.dayou.dto.FinanceFineSelectDTO;
import com.dayou.entity.FinanceFine;
import com.baomidou.mybatisplus.extension.service.IService;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.dayou.vo.FinanceFineVO;
import org.apache.poi.xssf.usermodel.XSSFWorkbook;
import org.springframework.web.multipart.MultipartFile;

import java.util.List;

/**
 * <p>
 * 超期未收款罚款表 服务类
 * </p>
 *
 * @author GouGengquan
 * @since 2025-04-07
 */
public interface IFinanceFineService extends IService<FinanceFine> {

    /**
     * 分页查询超期罚款
     * @param page 分页
     * @param financeFineSelectDTO 查询条件dto
     * @return Page<FinanceFineVO>
     */
    Page<FinanceFineVO> selectPage(Page page, FinanceFineSelectDTO financeFineSelectDTO);

    /**
     * 导出查询超期罚款
     * @param financeFineSelectDTO 查询条件dto
     * @return List<FinanceFineVO>
     */
    List<FinanceFineVO> exportList(FinanceFineSelectDTO financeFineSelectDTO);

    /**
     * 确认取消罚款金额
     * @return Boolean
     */
    Boolean cancelFineAmount(Long id);

    /**
     * 批量取消确认罚款金额
     * @return Boolean
     */
    Boolean batchCancelFineAmount(List<Long> ids);

    FinanceFine detail(Long id);

    Boolean add(FinanceFine financeFine);

    Boolean update(FinanceFine financeFine);

    Boolean delete(Long id);

    /**
     * 统计财务收款预警中超过270天的订单或产品新增到罚款表
     */
    void compileFineOrder();

    /**
     * 根据收款信息获取符合条件的罚款表信息
     * 且已确认罚款
     * @param orderFundId 订单收款id
     * @param productionFundId 产品收款id
     * @return FinanceFine
     */
    FinanceFine getFineByFundInfo(Long orderFundId, Long productionFundId);

    /**
     * 确认罚款
     * @param id
     * @return
     */
    Boolean confirmFineAmount(Long id);
}
