package com.dayou.service.impl;

import com.dayou.common.BaseEntity;
import com.dayou.entity.BusinessProductionBonusPoints;
import com.dayou.mapper.BusinessProductionBonusPointsMapper;
import com.dayou.service.IBusinessProductionBonusPointsService;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import org.springframework.stereotype.Service;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.conditions.update.LambdaUpdateWrapper;
import com.baomidou.mybatisplus.core.conditions.update.UpdateWrapper;
import com.dayou.utils.ExcelUtil;
import org.apache.poi.ss.usermodel.Cell;
import org.apache.poi.ss.usermodel.CellStyle;
import org.apache.poi.ss.usermodel.Row;
import org.apache.poi.ss.usermodel.Sheet;
import org.apache.poi.xssf.usermodel.XSSFWorkbook;
import org.springframework.web.multipart.MultipartFile;
import java.util.List;
import java.util.ArrayList;
import org.springframework.transaction.annotation.Transactional;
import com.dayou.enums.BatchTaskTypeEnum;

/**
 * <p>
 * 业务产品额外加减分(如疑难项目、总经理、部门综合加减分等) 服务实现类
 * </p>
 *
 * @author wucl
 * @since 2025-05-28
 */
@Service
public class BusinessProductionBonusPointsServiceImpl extends ServiceImpl<BusinessProductionBonusPointsMapper, BusinessProductionBonusPoints> implements IBusinessProductionBonusPointsService {


    @Override
    @SuppressWarnings("unchecked")
    public Page<BusinessProductionBonusPoints> selectPage(Page page,BusinessProductionBonusPoints businessProductionBonusPoints){
        return this.page(page, new QueryWrapper<BusinessProductionBonusPoints>(businessProductionBonusPoints));
    }


    @Override
    public BusinessProductionBonusPoints detail(Long id){
        return this.getById(id);
    }

    @Override
    public Boolean add(BusinessProductionBonusPoints businessProductionBonusPoints){
        return  this.save(businessProductionBonusPoints);
    }

    @Override
    public Boolean update(BusinessProductionBonusPoints businessProductionBonusPoints){
        return  this.updateById(businessProductionBonusPoints);
    }

    @Override
    public Boolean delete(Long id){
        //逻辑删除
        return this.removeById(id);
    }

    /**
     * 根据产品id与业务类型查询额外加减分信息集合
     * @param productionId 产品id
     * @param businessType 业务类型
     * @return List<BusinessProductionBonusPoints>
     */
    @Override
    public List<BusinessProductionBonusPoints> getList(Long productionId, String businessType) {
        return this.list(new LambdaQueryWrapper<BusinessProductionBonusPoints>()
                .eq(BaseEntity::getDeleted, 0)
                .eq(BusinessProductionBonusPoints::getProductionId, productionId)
                .eq(BusinessProductionBonusPoints::getBusinessType, businessType));
    }
}
